@@ -1,10 +1,14 @@
-from typing import Iterator
+from typing import Iterator, List, Optional
+
+from pipereport.telemetry.telemetry import Telemetry
+
 
 class BaseSink:
 
     def __init__(self, *args, **kwargs):
         self.attrs = kwargs 
         self.name = self.required_field("name")
+        self.telemetry = None
 
     def connect(self):
         raise NotImplementedError()
@@ -21,5 +25,8 @@ class BaseSink:
             raise Exception(f"Credential '{credential_name}' is not specified for sink!")
         return credentials[credential_name]
 
-    def write_block(self, source_iterator: Iterator[str], object_id: str, blocksize: int=-1):
+    def enable_telemetry(self, telemetry: Telemetry):
+        self.telemetry = telemetry
+
+    def write_block(self, source_iterator: Iterator[str], object_id: str, blocksize: int=-1, columns: Optional[List[str]] = None):
         raise NotImplementedError()
